@@ -3,7 +3,7 @@
 # ./data/po/update_pot.sh
 
 CPP_FILE_LIST=`find ./src -name '*.cpp' -print`
-PERL_FILE_LIST="./data/tracks/*/*.track ./data/*.cup"
+PERL_FILE_LIST="`find ./data -name '*.track' -print` `find ./data -name '*.challenge' -print` `find ./data -name '*.grandprix' -print`"
 
 echo "--------------------"
 echo "    Source Files :"
@@ -16,7 +16,7 @@ echo $PERL_FILE_LIST
 
 echo "---------------------------"
 echo "    Generating .pot file..."
-xgettext    -d supertuxkart -s --keyword=_ -p ./data/po -o supertuxkart.pot $CPP_FILE_LIST
-xgettext -j -L perl -d supertuxkart -s --keyword=_ -p ./data/po -o supertuxkart.pot $PERL_FILE_LIST
+xgettext    -d supertuxkart -s --keyword=_ --add-comments="I18N:" -p ./data/po -o supertuxkart.pot $CPP_FILE_LIST
+xgettext -j -L perl -d supertuxkart -s --keyword=_ --add-comments="I18N:" -p ./data/po -o supertuxkart.pot $PERL_FILE_LIST
 echo "    Done"
 echo "---------------------------"
\ No newline at end of file
