@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -37,11 +37,11 @@ class ActionMap
     void putEntry(Input, GameAction);
 
     GameAction getEntry(Input);
-    GameAction getEntry(InputType, int, int, int);
+    GameAction getEntry(Input::InputType, int, int, int);
 
   private:
     inline Key key(Input);
-    Key key(InputType, int, int, int);
+    Key key(Input::InputType, int, int, int);
 
     std::map<Key, GameAction> inputMap;
 
