@@ -48,7 +48,7 @@ void	GLDebugDrawer::draw3dText(const btVector3& location,const char* textString)
 
 void	GLDebugDrawer::reportErrorWarning(const char* warningString)
 {
-	printf(warningString);
+        printf("%s", warningString);
 }
 
 void	GLDebugDrawer::drawContactPoint(const btVector3& pointOnB,const btVector3& normalOnB,btScalar distance,int lifeTime,const btVector3& color)
