@@ -1,11 +1,11 @@
-//  $Id: config_controls.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: config_controls.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,13 +18,15 @@
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "config_controls.hpp"
-#include "widget_manager.hpp"
-#include "menu_manager.hpp"
-#include "translation.hpp"
+
 #if defined(WIN32) && !defined(__CYGWIN__)
 #  define snprintf _snprintf
 #endif
 
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "utils/translation.hpp"
+
 enum WidgetTokens
 {
     WTOK_TITLE,
@@ -41,7 +43,8 @@ ConfigControls::ConfigControls()
 {
     widget_manager->switchOrder();
     widget_manager->addTitleWgt( WTOK_TITLE, 60, 7, _("Edit controls for who?"));
-
+    widget_manager->hideWgtRect(WTOK_TITLE);
+    
     widget_manager->addTextButtonWgt( WTOK_PLYR1 , 60, 7, _("Player 1"));
     widget_manager->addTextButtonWgt( WTOK_PLYR2 , 60, 7, _("Player 2"));
     widget_manager->addTextButtonWgt( WTOK_PLYR3 , 60, 7, _("Player 3"));
