@@ -1,11 +1,11 @@
-//  $Id: config_display.hpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: config_display.hpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,14 +17,14 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#ifndef HEADER_CONFIGDISPLAY_H
-#define HEADER_CONFIGDISPLAY_H
+#ifndef HEADER_CONFIG_DISPLAY_HPP
+#define HEADER_CONFIG_DISPLAY_HPP
 
 #include <vector>
 
-#include "base_gui.hpp"
-#include "translation.hpp"
-#include "display_res_confirm.hpp"
+#include "gui/base_gui.hpp"
+#include "gui/display_res_confirm.hpp"
+#include "utils/translation.hpp"
 
 class ConfigDisplay: public BaseGUI
 {
