@@ -1,11 +1,11 @@
-//  $Id: config_sound.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: config_sound.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,12 +17,12 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#include "config_sound.hpp"
-#include "widget_manager.hpp"
 #include "user_config.hpp"
-#include "menu_manager.hpp"
-#include "translation.hpp"
-#include "sound_manager.hpp"
+#include "gui/config_sound.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "audio/sound_manager.hpp"
+#include "utils/translation.hpp"
 
 enum WidgetTokens
 {
@@ -38,6 +38,7 @@ ConfigSound::ConfigSound()
 {
     widget_manager->switchOrder();
     widget_manager->addTitleWgt(WTOK_TITLE, 50, 7, _("Sound Settings"));
+    widget_manager->hideWgtRect(WTOK_TITLE);
 
     widget_manager->setInitialActivationState(true);
     if( user_config->doMusic() )
