@@ -1,11 +1,11 @@
-//  $Id: grand_prix_ending.hpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: grand_prix_ending.hpp 2275 2008-09-18 03:24:19Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 Eduardo Hernandez Munoz
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -25,21 +25,23 @@
 class ssgBranch;
 class ssgTransform;
 class ssgContext;
+class SFXBase;
 
 class GrandPrixEnd: public BaseGUI
 {
 private:
-    ssgContext* m_context;
-    ssgTransform* m_kart;
-    int m_current_kart;
-    int m_kart_name_label;
-    char* m_score;
-    float m_clock;
+    ssgContext   *m_context;
+    ssgTransform *m_kart;
+    int           m_current_kart;
+    int           m_kart_name_label;
+    char         *m_score;
+    float         m_clock;
+    SFXBase      *m_winner_sound;
+
 
 public:
-    GrandPrixEnd();
-    ~GrandPrixEnd();
-
+         GrandPrixEnd();
+        ~GrandPrixEnd();
     void update(float dt);
     void select();
 };
