@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,17 +18,16 @@
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <set>
-#include "file_manager.hpp"
-#include "string_utils.hpp"
 #include "grand_prix_select.hpp"
-#include "widget_manager.hpp"
-#include "menu_manager.hpp"
 #include "race_manager.hpp"
-#include "track_manager.hpp"
 #include "material_manager.hpp"
-#include "user_config.hpp"
-#include "unlock_manager.hpp"
-#include "translation.hpp"
+#include "grand_prix_manager.hpp"
+#include "challenges/unlock_manager.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "tracks/track_manager.hpp"
+#include "tracks/track.hpp"
+#include "utils/translation.hpp"
 
 enum WidgetTokens
 {
@@ -49,22 +48,16 @@ GrandPrixSelect::GrandPrixSelect() : m_curr_track_img(0), m_clock(0.0f)
     widget_manager->switchOrder();
     widget_manager->addEmptyWgt(WTOK_TITLE, 60, 7);
 
-    // Findout which grand prixs are available and load them
-    std::set<std::string> result;
-    file_manager->listFiles(result, "data");
-    int nId = 0;
-    for(std::set<std::string>::iterator i  = result.begin();
-            i != result.end()  ; i++)
-        {
-            if (StringUtils::has_suffix(*i, ".cup"))
-            {
-                CupData cup(*i);
-                if(unlock_manager->isLocked(cup.getName())) continue;
-                m_all_cups.push_back(cup);
-                widget_manager->addTextButtonWgt(WTOK_FIRSTPRIX + nId, 60, 7, cup.getName() );
-                nId++;
-            }   // if
-        }   // for i
+    int nId=0;
+    m_gp_index.clear();
+    for(unsigned int i=0; i<grand_prix_manager->getNumberOfGrandPrix(); i++)
+    {
+        const GrandPrixData *gp = grand_prix_manager->getGrandPrix(i);
+        if(unlock_manager->isLocked(gp->getId())) continue;
+        widget_manager->addTextButtonWgt(WTOK_FIRSTPRIX + nId, 60, 7, gp->getName() );
+        m_gp_index.push_back(i);
+        nId++;
+    }   // for i
 
     widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 100, 1 );
 
@@ -105,19 +98,19 @@ void GrandPrixSelect::update(float dt)
     if( widget_manager->selectionChanged() &&
         !( SELECTED_TOKEN < WTOK_FIRSTPRIX ))
     {
-        const int CUP_NUM = SELECTED_TOKEN - WTOK_FIRSTPRIX;
-        const int NUM_TRACKS = (int)m_all_cups[CUP_NUM].getTrackCount();
+        const int NUM           = m_gp_index[SELECTED_TOKEN - WTOK_FIRSTPRIX];
+        const GrandPrixData *gp = grand_prix_manager->getGrandPrix(NUM);
+        const int NUM_TRACKS    = gp->getTrackCount();
 
-        const CupData &cup = m_all_cups[CUP_NUM];
-        widget_manager->setWgtText(WTOK_DESCRIPTION, cup.getDescription());
+        widget_manager->setWgtText(WTOK_DESCRIPTION, gp->getDescription());
 
 
         std::string track_list;
-        m_cup_tracks = m_all_cups[CUP_NUM].getTracks();
+        m_gp_tracks = gp->getTracks();
 
         for( int i = 0; i < NUM_TRACKS; ++i )
         {
-            track_list.append( track_manager->getTrack( m_cup_tracks[i] )->getName() );
+            track_list.append( track_manager->getTrack( m_gp_tracks[i] )->getName() );
             track_list.push_back('\n');
         }
         widget_manager->setWgtText( WTOK_TRACKS, track_list );
@@ -130,10 +123,10 @@ void GrandPrixSelect::update(float dt)
 
         for( int i = 0; i < NUM_TRACKS; ++i )
         {
-            img_filename = track_manager->getTrack( m_cup_tracks[i] )->getTopviewFile();
+            img_filename = track_manager->getTrack( m_gp_tracks[i] )->getTopviewFile();
             if( img_filename.empty() )
             {
-                img_filename = track_manager->getTrack( m_cup_tracks[i] )->getScreenshotFile();
+                img_filename = track_manager->getTrack( m_gp_tracks[i] )->getScreenshotFile();
                 if( img_filename.empty() ) continue;
             }
 
@@ -142,14 +135,14 @@ void GrandPrixSelect::update(float dt)
             m_track_imgs.push_back(mat->getState()->getTextureHandle());
         }
 
-        if( !( m_track_imgs.empty() ))
+        if( !m_track_imgs.empty() )
         {
             m_clock = 0.0f;
             m_curr_track_img = 0;
 
             widget_manager->showWgtTexture( WTOK_IMG );
             widget_manager->setWgtTexture( WTOK_IMG,
-                m_track_imgs[ m_curr_track_img ] );
+                                           m_track_imgs[ m_curr_track_img ] );
             widget_manager->setWgtColor( WTOK_IMG, WGT_WHITE );
         }
         else
@@ -159,7 +152,7 @@ void GrandPrixSelect::update(float dt)
         }
     }
 
-    if( !( m_track_imgs.empty() ))
+    if( !m_track_imgs.empty() )
     {
         m_clock += dt;
 
@@ -170,8 +163,8 @@ void GrandPrixSelect::update(float dt)
             ++m_curr_track_img;
             if( m_curr_track_img >= m_track_imgs.size() ) m_curr_track_img = 0;
 
-            widget_manager->setWgtTexture( WTOK_IMG,
-                m_track_imgs[ m_curr_track_img ] );
+            widget_manager->setWgtTexture(WTOK_IMG,
+                                          m_track_imgs[ m_curr_track_img ] );
         }
     }
 
@@ -190,7 +183,8 @@ void GrandPrixSelect::select()
         menu_manager->popMenu();
         return;
     }
-    race_manager->setGrandPrix(m_all_cups[CLICKED_TOKEN-WTOK_FIRSTPRIX]);
+    const GrandPrixData *gp=grand_prix_manager->getGrandPrix(m_gp_index[CLICKED_TOKEN-WTOK_FIRSTPRIX]);
+    race_manager->setGrandPrix(*gp);
     menu_manager->pushMenu(MENUID_RACE_OPTIONS);
 }   // select
 
