@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,15 +17,13 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#include "help_page_one.hpp"
-#include "widget_manager.hpp"
-#include "race_manager.hpp"
-#include "menu_manager.hpp"
+#include "gui/help_page_one.hpp"
+
 #include "user_config.hpp"
-#include "player.hpp"
-#include "collectable_manager.hpp"
-#include "material.hpp"
-#include "translation.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "items/item_manager.hpp"
+#include "utils/translation.hpp"
 
 enum WidgetTokens
 {
@@ -36,7 +34,8 @@ enum WidgetTokens
     WTOK_MSG5,
     WTOK_MSG6,
     WTOK_MSG7,
-
+    WTOK_MSG8,
+    
     WTOK_LOCK,
 
     WTOK_SECOND_PAGE,
@@ -72,30 +71,30 @@ HelpPageOne::HelpPageOne()
     widget_manager->breakLine();
 
     widget_manager->addTextWgt( WTOK_MSG2, 60, 7,
-        _("Grab blue boxes and coins") );
+        _("Grab blue boxes and nitro") );
     widget_manager->addTextWgt( WTOK_MSG3, 30, 7, _("Avoid bananas") );
     widget_manager->breakLine();
 
     /*Rotating 3D models*/
-	ssgEntity* hm = herring_manager->getHerringModel(HE_RED);
+	ssgEntity* hm = item_manager->getItemModel(ITEM_BONUS_BOX);
     ssgDeRefDelete(m_box);
     m_box = new ssgTransform;
     m_box->ref();
     m_box->addKid(hm);
 
-    hm = herring_manager->getHerringModel(HE_SILVER);
+    hm = item_manager->getItemModel(ITEM_SILVER_COIN);
     ssgDeRefDelete(m_silver_coin);
     m_silver_coin = new ssgTransform;
     m_silver_coin->ref();
     m_silver_coin->addKid(hm);
 
-    hm = herring_manager->getHerringModel(HE_GOLD);
+    hm = item_manager->getItemModel(ITEM_GOLD_COIN);
     ssgDeRefDelete(m_gold_coin);
     m_gold_coin = new ssgTransform;
     m_gold_coin->ref();
     m_gold_coin->addKid(hm);
 
-    hm = herring_manager->getHerringModel(HE_GREEN);
+    hm = item_manager->getItemModel(ITEM_BANANA);
     ssgDeRefDelete(m_banana);
     m_banana = new ssgTransform;
     m_banana->ref();
@@ -104,13 +103,13 @@ HelpPageOne::HelpPageOne()
     /*Empty widget to cover the space for the 3D models*/
     widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 100, 15);
     widget_manager->breakLine();
-
+/*
     widget_manager->addTextWgt(WTOK_MSG4, 100, 13,
 //Next line starts at column 0 to avoid spaces in the GUI
 _("At high speeds wheelies drive you faster, but you can't steer. If you\n\
 get stuck or fall too far, use the rescue button to get back on track."));
     widget_manager->setWgtResizeToText( WTOK_MSG4, false );
-    widget_manager->breakLine();
+    widget_manager->breakLine();*/
 
     widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 100, 1);
     widget_manager->breakLine();
@@ -122,10 +121,7 @@ get stuck or fall too far, use the rescue button to get back on track."));
     widget_manager->breakLine();
 
     widget_manager->addTextWgt(WTOK_MSG6, 100, 17,
-_("Collecting coins increases the number of collectables you receive.\n\
-After 5 silver coins, each blue box will yield 2 collectables,\nafter 10,\
- 3 collectables and so on.\nEach gold coin is worth 3 silver coins, \
-so look out for them!"));
+_("Collecting nitro allows you to get speed boosts whenever you\nwish by pressing the appropriate key. You can see your\ncurrent level of nitro in the bar at the right of the game screen."));
     widget_manager->setWgtResizeToText( WTOK_MSG6, false);
     widget_manager->breakLine();
     widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 100, 1);
@@ -135,20 +131,30 @@ so look out for them!"));
 _("If you see a button with a lock like the one to the right,\n\
 you need to complete a challenge to unlock it."));
 
-    widget_manager->addImgWgt(WTOK_LOCK, 6, 8, 0);
-    widget_manager->setWgtTexture(WTOK_LOCK, "gui_help_lock.rgb", false);
+    widget_manager->addImgWgt(WTOK_LOCK, 20, 8, 0);
+    widget_manager->setWgtLockTexture(WTOK_LOCK);
     widget_manager->breakLine();
 
     widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 100, 1);
     widget_manager->breakLine();
 
-    /*Buttons at the bottom*/
-    widget_manager->addTextButtonWgt(WTOK_SECOND_PAGE, 20, 7,
-        _("Next help screen"));
+    
+    widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 100, 1);
     widget_manager->breakLine();
-
+    
+    widget_manager->addTextWgt(WTOK_MSG8, 87, 8,
+                               _("The 'sharp turn' key allows you to do sharp turns\nand have better control in tight curves"));
+    widget_manager->breakLine();
+    
+    /*Buttons at the bottom*/
+    widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 100, 16);
+    widget_manager->breakLine();
+    widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 30, 7);
     widget_manager->addTextButtonWgt(WTOK_QUIT, 40, 7,
-        _("Go back to the menu"));
+                                     _("Back to the menu"));
+    
+    widget_manager->addTextButtonWgt(WTOK_SECOND_PAGE, 30, 7,
+        _("Next >"));
 
     widget_manager->layout( WGT_AREA_TOP );
 }   // HelpPageOne
