@@ -1,11 +1,11 @@
-//  $Id: menu_manager.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: menu_manager.cpp 2882 2009-01-12 00:49:25Z auria $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 Patrick Ammann <pammann@aro.ch>
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,57 +22,67 @@
 //This is needed in various platforms, but not all
 # include <algorithm>
 
-#include "menu_manager.hpp"
-
-#include "main_menu.hpp"
-#include "char_sel.hpp"
-#include "game_mode.hpp"
-#include "race_options.hpp"
-#include "options.hpp"
-#include "track_sel.hpp"
-#include "num_players.hpp"
-#include "config_controls.hpp"
-#include "config_display.hpp"
-#include "display_res_confirm.hpp"
-#include "config_sound.hpp"
-#include "player_controls.hpp"
-#include "race_gui.hpp"
-#include "race_results_gui.hpp"
-#include "grand_prix_ending.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/main_menu.hpp"
+#include "gui/char_sel.hpp"
+#include "gui/game_mode.hpp"
+#include "gui/race_options.hpp"
+#include "gui/options.hpp"
+#include "gui/track_sel.hpp"
+#include "gui/num_players.hpp"
+#include "gui/config_controls.hpp"
+#include "gui/config_display.hpp"
+#include "gui/display_res_confirm.hpp"
+#include "gui/config_sound.hpp"
+#include "gui/player_controls.hpp"
+#include "gui/race_gui.hpp"
+#include "gui/race_results_gui.hpp"
+#include "gui/grand_prix_ending.hpp"
+#include "gui/race_menu.hpp"
+#include "gui/help_page_one.hpp"
+#include "gui/help_page_two.hpp"
+#include "gui/help_page_three.hpp"
+#include "gui/credits_menu.hpp"
+#include "gui/grand_prix_select.hpp"
+#include "gui/widget_manager.hpp"
+#include "gui/challenges_menu.hpp"
+#include "gui/feature_unlocked.hpp"
+#include "gui/start_race_feedback.hpp"
+#include "gui/network_gui.hpp"
+#include "audio/sfx_manager.hpp"
+#include "audio/sfx_base.hpp"
 #include "race_manager.hpp"
-#include "game_manager.hpp"
-#include "race_menu.hpp"
-#include "help_page_one.hpp"
-#include "help_page_two.hpp"
-#include "help_page_three.hpp"
-#include "credits_menu.hpp"
-#include "grand_prix_select.hpp"
-#include "sound_manager.hpp"
 #include "sdldrv.hpp"
+#include "main_loop.hpp"
 #include "user_config.hpp"
-#include "widget_manager.hpp"
-#include "challenges_menu.hpp"
-#include "feature_unlocked.hpp"
-#include "leader_result.hpp"
-#include "start_race_feedback.hpp"
+#include "network/network_manager.hpp"
 
 using namespace std;
 
-MenuManager* menu_manager= new MenuManager();
+MenuManager* menu_manager = 0;
 
+/** Initialises the menu manager and creates the SFX objects.
+ */
 MenuManager::MenuManager()
 {
     m_current_menu = NULL;
     m_RaceGUI      = NULL;
-    m_change_menu = false;
-}
+    m_change_menu  = false;
+    m_select_sound = sfx_manager->newSFX(SFXManager::SOUND_SELECT_MENU);
+    m_back_sound   = sfx_manager->newSFX(SFXManager::SOUND_BACK_MENU);
+}   // MenuManager
 
 //-----------------------------------------------------------------------------
+/** Destroys the menu manager and frees any allocated memory.
+ */
 MenuManager::~MenuManager()
 {
     delete m_current_menu;
+    sfx_manager->deleteSFX(m_back_sound);
+    sfx_manager->deleteSFX(m_select_sound);
 }
 
+//-----------------------------------------------------------------------------
 /** Puts the given menu into the menu stack and saves the widgetToken of
   * the last selected widget for later reactivation.
   */
@@ -91,11 +101,11 @@ void MenuManager::pushMenu(MenuManagerIDs id)
 
     if( MENUID_EXITGAME == id )
     {
-        sound_manager->playSfx(SOUND_BACK_MENU);
+        m_back_sound->play();
     }
     else
     {
-        if( !is_startup ) sound_manager->playSfx(SOUND_SELECT_MENU);
+        if(!is_startup) m_select_sound->play();
         else is_startup = false;
     }
 
@@ -110,12 +120,18 @@ void MenuManager::pushMenu(MenuManagerIDs id)
     m_change_menu = true;
 }
 
+//-----------------------------------------------------------------------------
+const bool MenuManager::isMainMenuActive() const
+{
+    return m_menu_stack[ m_menu_stack.size()-1 ].first == MENUID_MAINMENU;
+}
+
 //-----------------------------------------------------------------------------
 void MenuManager::popMenu()
 {
-    sound_manager->playSfx(SOUND_BACK_MENU);
+    m_back_sound->play();
 
-	m_menu_stack.pop_back();
+    m_menu_stack.pop_back();
     if( m_current_menu ) m_current_menu->lockInput();
     m_change_menu = true;
 }
@@ -132,7 +148,7 @@ void MenuManager::update()
             && m_current_menu == m_RaceGUI)
         {
             m_RaceGUI = 0;
-            inputDriver->setMode(MENU);
+            inputDriver->setMode(SDLDriver::MENU);
         }
 
         delete m_current_menu;
@@ -148,6 +164,11 @@ void MenuManager::update()
             {
             case MENUID_MAINMENU:
                 m_current_menu= new MainMenu();
+                // in this case the network entry can be removed, resulting
+                // in warnings etc. if the widget manager then tries to select
+                // the widget again. To avoid this, set the saved widget to NONE.
+                if(network_manager->getMode()!=NetworkManager::NW_NONE) 
+                    saved_widget=WidgetManager::WGT_NONE;
                 break;
             case MENUID_CHALLENGES:
                 m_current_menu= new ChallengesMenu();
@@ -177,16 +198,13 @@ void MenuManager::update()
                 m_current_menu= new NumPlayers();
                 break;
             case MENUID_RACE:
-                inputDriver->setMode(INGAME);
+                inputDriver->setMode(SDLDriver::INGAME);
                 m_current_menu = new RaceGUI();
                 m_RaceGUI      = m_current_menu;
                 break;
             case MENUID_RACERESULT:
                 m_current_menu= new RaceResultsGUI();
                 break;
-            case MENUID_LEADERRESULT:
-                m_current_menu= new LeaderResult();
-                break;
             case MENUID_GRANDPRIXEND:
                 m_current_menu= new GrandPrixEnd();
                 break;
@@ -198,7 +216,7 @@ void MenuManager::update()
                 break;
             case MENUID_EXITGAME:
                 m_menu_stack.clear();
-                game_manager->abort();
+                main_loop->abort();
                 break;
 
             case MENUID_CONFIG_CONTROLS:
@@ -242,6 +260,10 @@ void MenuManager::update()
                 break;
             case MENUID_START_RACE_FEEDBACK:
                 m_current_menu = new StartRaceFeedback();
+                break;
+            case MENUID_NETWORK_GUI:
+                m_current_menu = new NetworkGUI();
+                break;
             default:
                 break;
             }   // switch
