@@ -1,11 +1,11 @@
-//  $Id: num_players.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: num_players.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,11 +17,13 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+#include "gui/num_players.hpp"
+
 #include "race_manager.hpp"
-#include "num_players.hpp"
-#include "widget_manager.hpp"
-#include "menu_manager.hpp"
-#include "translation.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "network/network_manager.hpp"
+#include "utils/translation.hpp"
 
 enum WidgetTokens
 {
@@ -62,8 +64,11 @@ void NumPlayers::select()
     case WTOK_PLAYER_2:
     case WTOK_PLAYER_3:
     case WTOK_PLAYER_4:
-        race_manager->setNumPlayers(widget_manager->getSelectedWgt());
-        menu_manager->pushMenu(MENUID_GAMEMODE);
+        race_manager->setNumLocalPlayers(widget_manager->getSelectedWgt());
+        if(network_manager->getMode()==NetworkManager::NW_CLIENT)
+            menu_manager->pushMenu(MENUID_CHARSEL_P1);
+        else
+            menu_manager->pushMenu(MENUID_GAMEMODE);
         break;
     case WTOK_QUIT:
         menu_manager->popMenu();
