@@ -1,4 +1,4 @@
-//  $Id: race_gui.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: race_gui.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004-2005 Steve Baker <sjbaker1@airmail.net>
@@ -6,7 +6,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,26 +18,26 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#include "race_gui.hpp"
+#include "gui/race_gui.hpp"
 
 #include "input.hpp"
 #include "sdldrv.hpp"
-
 #include "user_config.hpp"
 #include "history.hpp"
-#include "track.hpp"
-#include "material_manager.hpp"
-#include "menu_manager.hpp"
-#include "sound_manager.hpp"
 #include "race_manager.hpp"
+#include "material_manager.hpp"
+#include "audio/sound_manager.hpp"
+#include "gui/font.hpp"
+#include "gui/menu_manager.hpp"
+#include "tracks/track.hpp"
+#include "utils/constants.hpp"
+#include "utils/translation.hpp"
 
 #undef USE_WIDGET_MANAGER
 #ifdef USE_WIDGET_MANAGER
-#include "widget_manager.hpp"
+#include "gui/widget_manager.hpp"
 #endif
 
-#include "translation.hpp"
-#include "font.hpp"
 
 #ifdef USE_WIDGET_MANAGER
 //MAX_TOP_POS is the maximum number of racers to be shown in the bar to the
@@ -97,14 +97,14 @@ RaceGUI::RaceGUI()
     m_pos_string[9] = "9th";
     m_pos_string[10] = "10th";
 
-    //FIXME: Temporary, we need a better icon here
-    m_steering_wheel_icon = material_manager->getMaterial("wheel.rgb");
-    m_steering_wheel_icon->getState()->disable(GL_CULL_FACE);
     m_speed_back_icon = material_manager->getMaterial("speedback.rgb");
     m_speed_back_icon->getState()->disable(GL_CULL_FACE);
     m_speed_fore_icon = material_manager->getMaterial("speedfore.rgb");
     m_speed_fore_icon->getState()->disable(GL_CULL_FACE);
-
+    
+    m_plunger_face = material_manager->getMaterial("plungerface.rgb");
+    m_plunger_face->getState()->disable(GL_CULL_FACE);
+    
     m_fps_counter = 0;
     m_fps_string[0]=0;
     m_fps_timer.reset();
@@ -157,7 +157,7 @@ RaceGUI::handle(GameAction ga, int value)
 		int playerNo = ka / KC_COUNT;
 		ka = ka % KC_COUNT;
 		
-		world->getPlayerKart(playerNo)->action((KartAction) ka, value);
+		RaceManager::getWorld()->getLocalPlayerKart(playerNo)->action((KartAction) ka, value);
 		
 		return;
 	}
@@ -167,25 +167,25 @@ RaceGUI::handle(GameAction ga, int value)
 	
 	switch (ga)
 	{
-		case GA_DEBUG_ADD_SPARK:
+		case GA_DEBUG_ADD_BOWLING:
 			if (race_manager->getNumPlayers() ==1 )
 			{
-				Kart* kart = world->getPlayerKart(0);
-				kart->setCollectable(COLLECT_SPARK, 10000);
+				Kart* kart = RaceManager::getWorld()->getLocalPlayerKart(0);
+				kart->setPowerup(POWERUP_BOWLING, 10000);
 			}
 			break;
 		case GA_DEBUG_ADD_MISSILE:
-			if (race_manager->getNumPlayers() ==1 )
+//FIXME			if (race_manager->getNumPlayers() ==1 )
 			{
-				Kart* kart = world->getPlayerKart(0);
-				kart->setCollectable(COLLECT_MISSILE, 10000);
+				Kart* kart = RaceManager::getPlayerKart(0);
+				kart->setPowerup(POWERUP_PLUNGER, 10000);
 			}
 			break;
 		case GA_DEBUG_ADD_HOMING:
 			if (race_manager->getNumPlayers() ==1 )
 			{
-				Kart* kart = world->getPlayerKart(0);
-				kart->setCollectable(COLLECT_HOMING, 10000);
+				Kart* kart = RaceManager::getPlayerKart(0);
+				kart->setPowerup(POWERUP_CAKE, 10000);
 			}
 			break;
 		case GA_DEBUG_TOGGLE_FPS:
@@ -217,7 +217,7 @@ RaceGUI::handle(GameAction ga, int value)
 			// Fall through to put the game into pause mode.
 #endif
 		case GA_LEAVE_RACE:
-			world->pause();
+			RaceManager::getWorld()->pause();
 			menu_manager->pushMenu(MENUID_RACEMENU);
 		break;
 		case GA_DEBUG_HISTORY:
@@ -232,9 +232,8 @@ RaceGUI::handle(GameAction ga, int value)
 //-----------------------------------------------------------------------------
 void RaceGUI::update(float dt)
 {
-    assert(world != NULL);
     drawStatusText(dt);
-    cleanupMessages();
+    cleanupMessages(dt);
 
     BaseGUI::update( dt );
 }   // update
@@ -260,13 +259,12 @@ void RaceGUI::drawFPS ()
 //-----------------------------------------------------------------------------
 void RaceGUI::drawTimer ()
 {
-    if(world->getPhase()!=World::RACE_PHASE         &&
-       world->getPhase()!=World::DELAY_FINISH_PHASE   ) return;
+    assert(RaceManager::getWorld() != NULL);
+    
+    if(!RaceManager::getWorld()->shouldDrawTimer()) return;
     char str[256];
-
-    assert(world != NULL);
-
-    TimeToString(world->getTime(), str);
+    
+    TimeToString(RaceManager::getWorld()->getTime(), str);
 #ifdef USE_WIDGET_MANAGER
     widget_manager->showWgtText( WTOK_CLOCK );
     widget_manager->setWgtText( WTOK_CLOCK, str );
@@ -281,38 +279,39 @@ void RaceGUI::drawTimer ()
 
 void RaceGUI::drawMap ()
 {
+    // arenas currently don't have a map.
+    if(RaceManager::getTrack()->isArena()) return;
+    
     glDisable ( GL_TEXTURE_2D ) ;
-    assert(world != NULL);
+    assert(RaceManager::getWorld() != NULL);
     int xLeft = 10;
     int yTop   =  10;
 
-    world -> m_track -> draw2Dview ( (float)xLeft,   (float)yTop   );
+    RaceManager::getTrack() -> draw2Dview ( (float)xLeft,   (float)yTop   );
 
     glBegin ( GL_QUADS ) ;
 
     for ( unsigned int i = 0 ; i < race_manager->getNumKarts() ; i++ )
     {
-        sgCoord *c ;
-
-        Kart* kart = world->getKart(i);
+        Kart* kart = RaceManager::getKart(i);
         if(kart->isEliminated()) continue;   // don't draw eliminated kart
-        glColor3fv ( *kart->getColor());
-        c          = kart->getCoord () ;
+        glColor3fv ( kart->getColor().toFloat());
+	const Vec3& xyz = kart->getXYZ();
 
         /* If it's a player, draw a bigger sign */
         if (kart -> isPlayerKart ())
         {
-            world -> m_track->glVtx ( c->xyz, (float)xLeft+3, (float)yTop+3);
-            world -> m_track->glVtx ( c->xyz, (float)xLeft-2, (float)yTop+3);
-            world -> m_track->glVtx ( c->xyz, (float)xLeft-2, (float)yTop-2);
-            world -> m_track->glVtx ( c->xyz, (float)xLeft+3, (float)yTop-2);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft+3, (float)yTop+3);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft-2, (float)yTop+3);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft-2, (float)yTop-2);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft+3, (float)yTop-2);
         }
         else
         {
-            world -> m_track->glVtx ( c->xyz, (float)xLeft+2, (float)yTop+2);
-            world -> m_track->glVtx ( c->xyz, (float)xLeft-1, (float)yTop+2);
-            world -> m_track->glVtx ( c->xyz, (float)xLeft-1, (float)yTop-1);
-            world -> m_track->glVtx ( c->xyz, (float)xLeft+2, (float)yTop-1);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft+2, (float)yTop+2);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft-1, (float)yTop+2);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft-1, (float)yTop-1);
+            RaceManager::getTrack() -> glVtx ( xyz.toFloat(), (float)xLeft+2, (float)yTop-1);
         }
     }
 
@@ -322,94 +321,44 @@ void RaceGUI::drawMap ()
 
 //-----------------------------------------------------------------------------
 // Draw players position on the race
-void RaceGUI::drawPlayerIcons ()
+void RaceGUI::drawPlayerIcons (const KartIconDisplayInfo* info)
 {
-    assert(world != NULL);
+    assert(RaceManager::getWorld() != NULL);
 
     int x = 5;
     int y;
-#define ICON_WIDTH 40
-#define ICON_PLAYER_WIDHT 50
+    int ICON_WIDTH=40;
+    int ICON_PLAYER_WIDTH=50;
+    if(user_config->m_height<600)
+    {
+        ICON_WIDTH        = 27;
+        ICON_PLAYER_WIDTH = 35;
+    }
 
     //glEnable(GL_TEXTURE_2D);
     Material *last_players_gst = 0;
-    int   laps_of_leader       = -1;
-    float time_of_leader       = -1;
-    // Find the best time for the lap. We can't simply use
-    // the time of the kart at position 1, since the kart
-    // might have been overtaken by now
-    for(unsigned int i = 0; i < race_manager->getNumKarts() ; i++)
-    {
-        Kart* kart     = world->getKart(i);
-        if(kart->isEliminated()) continue;
-        float lap_time = kart->getTimeAtLap();
-        int laps       = kart->getLap();
-
-        if(laps > laps_of_leader)
-        {
-            // more laps than current leader --> new leader and new time computation
-            laps_of_leader = laps;
-            time_of_leader = lap_time;
-        } else if(laps == laps_of_leader)
-        {
-            // Same number of laps as leader: use fastest time
-            time_of_leader=std::min(time_of_leader,lap_time);
-        }
-    }   // for i<getNumKarts
 
     int bFirst                 = 1;
-    for(unsigned int i = 0; i < race_manager->getNumKarts() ; i++)
+    glDisable(GL_CULL_FACE);
+    
+    const unsigned int kart_amount = race_manager->getNumKarts();
+    for(unsigned int i = 0; i < kart_amount ; i++)
     {
-        Kart* kart   = world->getKart(i);
+        Kart* kart   = RaceManager::getKart(i);
         if(kart->isEliminated()) continue;
-        int position = kart->getPosition();
-        int lap      = kart->getLap();
+        const int position = kart->getPosition();
 
-        y = user_config->m_height*3/4-20 - ((position-1)*(ICON_PLAYER_WIDHT+2));
+        y = user_config->m_height*7/8-20 - ( (position == -1 ? i : position-1)*(ICON_PLAYER_WIDTH+2));
 
-        // draw text
-        GLfloat COLORS[] = {1.0f, 1.0f, 1.0f, 1.0f};
-        int numLaps = race_manager->getNumLaps();
-
-        if(lap>=numLaps)
-        {  // kart is finished, display in green
-            COLORS[1] = COLORS[2] = 0;
-        }
-        else if(lap>=0 && numLaps>1)
-        {
-            COLORS[1] = COLORS[2] = 1.0f-(float)lap/((float)numLaps-1.0f);
-        }
-
-        glDisable(GL_CULL_FACE);
-
-        if(laps_of_leader>0 &&    // Display position during first lap
-           (world->getTime() - kart->getTimeAtLap()<5.0f || lap!=laps_of_leader) &&
-           race_manager->raceHasLaps())
-        {  // Display for 5 seconds
-            char str[256];
-            if(position==1)
-            {
-                str[0]=' '; str[1]=0;
-                TimeToString(kart->getTimeAtLap(), str+1);
-            }
-            else
-            {
-                float timeBehind;
-                timeBehind = (lap==laps_of_leader ? kart->getTimeAtLap() : world->getTime())
-                    - time_of_leader;
-                str[0]='+'; str[1]=0;
-                TimeToString(timeBehind, str+1);
-            }
-            font_race->PrintShadow(str, 30, ICON_PLAYER_WIDHT+x, y+5,
-                                   COLORS);
-        }
-        if(race_manager->getRaceMode()==RaceManager::RM_FOLLOW_LEADER && i==0)
+        GLfloat COLOR[] = {info[i].r, info[i].g, info[i].b, 1.0f};
+        font_race->PrintShadow(info[i].time.c_str(), 30, ICON_PLAYER_WIDTH+x, y+5, COLOR);
+        
+        if(info[i].special_title.length() >0)
         {
             GLfloat const RED[] = { 1.0f, 0, 0, 1.0f};
-            font_race->PrintShadow(_("Leader"), 30, ICON_PLAYER_WIDHT+x, y+5,
-                                   RED );
+            font_race->PrintShadow(info[i].special_title.c_str(), 30, ICON_PLAYER_WIDTH+x, y+5, RED );
         }
-
+        
         glEnable(GL_CULL_FACE);
 
         bFirst = 0;
@@ -432,9 +381,9 @@ void RaceGUI::drawPlayerIcons ()
         if (kart -> isPlayerKart ())
         {
             glTexCoord2f ( 0, 0 ) ; glVertex2i ( x                  , y                   ) ;
-            glTexCoord2f ( 1, 0 ) ; glVertex2i ( x+ICON_PLAYER_WIDHT, y                   ) ;
-            glTexCoord2f ( 1, 1 ) ; glVertex2i ( x+ICON_PLAYER_WIDHT, y+ICON_PLAYER_WIDHT ) ;
-            glTexCoord2f ( 0, 1 ) ; glVertex2i ( x                  , y+ICON_PLAYER_WIDHT ) ;
+            glTexCoord2f ( 1, 0 ) ; glVertex2i ( x+ICON_PLAYER_WIDTH, y                   ) ;
+            glTexCoord2f ( 1, 1 ) ; glVertex2i ( x+ICON_PLAYER_WIDTH, y+ICON_PLAYER_WIDTH ) ;
+            glTexCoord2f ( 0, 1 ) ; glVertex2i ( x                  , y+ICON_PLAYER_WIDTH ) ;
         }
         else
         {
@@ -449,40 +398,43 @@ void RaceGUI::drawPlayerIcons ()
         glDisable(GL_CULL_FACE);
         char str[256];
 
-        sprintf(str, "%d", kart->getPosition());
-        font_race->PrintShadow(str, 33, x-7, y-4);
-
-        // FIXME: translation
-        if (kart->getPosition() == 1)
-            font_race->PrintShadow("st", 13, x-7+17, y-4+17);
-        else if (kart->getPosition() == 2)
-            font_race->PrintShadow("nd", 13, x-7+17, y-4+17);
-        else if (kart->getPosition() == 3)
-            font_race->PrintShadow("rd", 13, x-7+17, y-4+17);
-        else
-            font_race->PrintShadow("th", 13, x-7+17, y-4+17);
-
-        glEnable(GL_CULL_FACE);
-    }
+        if(position != -1)
+        {
+            sprintf(str, "%d", position);
+            font_race->PrintShadow(str, 33, x-7, y-4);
+            
+            // FIXME: translation
+            if (kart->getPosition() == 1)
+                font_race->PrintShadow("st", 13, x-7+17, y-4+17);
+            else if (kart->getPosition() == 2)
+                font_race->PrintShadow("nd", 13, x-7+17, y-4+17);
+            else if (kart->getPosition() == 3)
+                font_race->PrintShadow("rd", 13, x-7+17, y-4+17);
+            else
+                font_race->PrintShadow("th", 13, x-7+17, y-4+17);
+        }
+    } // next kart
+    
+    glEnable(GL_CULL_FACE);
 }   // drawPlayerIcons
 
 //-----------------------------------------------------------------------------
-void RaceGUI::drawCollectableIcons ( Kart* player_kart, int offset_x,
+void RaceGUI::drawPowerupIcons ( Kart* player_kart, int offset_x,
                                      int offset_y, float ratio_x,
                                      float ratio_y                    )
 {
     // If player doesn't have anything, do nothing.
-    Collectable* collectable=player_kart->getCollectable();
-    if(collectable->getType() == COLLECT_NOTHING) return;
+    Powerup* powerup=player_kart->getPowerup();
+    if(powerup->getType() == POWERUP_NOTHING) return;
 
     // Originally the hardcoded sizes were 320-32 and 400
     int x1 = (int)((user_config->m_width/2-32) * ratio_x) + offset_x ;
     int y1 = (int)(user_config->m_height*5/6 * ratio_y)      + offset_y;
 
     int nSize=(int)(64.0f*std::min(ratio_x, ratio_y));
-    collectable->getIcon()->apply();
+    powerup->getIcon()->apply();
 
-    int n  = player_kart->getNumCollectables() ;
+    int n  = player_kart->getNumPowerup() ;
 
     if ( n > 5 ) n = 5 ;
     if ( n < 1 ) n = 1 ;
@@ -499,7 +451,7 @@ void RaceGUI::drawCollectableIcons ( Kart* player_kart, int offset_x,
     }   // for i
     glEnd () ;
 
-}   // drawCollectableIcons
+}   // drawPowerupIcons
 
 //-----------------------------------------------------------------------------
 /* Energy meter that gets filled with coins */
@@ -516,8 +468,8 @@ void RaceGUI::drawCollectableIcons ( Kart* player_kart, int offset_x,
 void RaceGUI::drawEnergyMeter ( Kart *player_kart, int offset_x, int offset_y,
                                 float ratio_x, float ratio_y             )
 {
-    float state = (float)(player_kart->getNumHerring()) /
-                  MAX_HERRING_EATEN;
+    float state = (float)(player_kart->getEnergy()) /
+                  MAX_ITEMS_COLLECTED;
     int x = (int)((user_config->m_width-24) * ratio_x) + offset_x;
     int y = (int)(250 * ratio_y) + offset_y;
     int w = (int)(16 * ratio_x);
@@ -525,10 +477,10 @@ void RaceGUI::drawEnergyMeter ( Kart *player_kart, int offset_x, int offset_y,
     int wl = (int)(ratio_x);
     if(wl < 1)
         wl = 1;
-    const int GRADS = (int)(MAX_HERRING_EATEN/5);  // each graduation equals 5 herring
+    const int GRADS = (int)(MAX_ITEMS_COLLECTED/5);  // each graduation equals 5 items
     int gh = (int)(h/GRADS);  //graduation height
     float coin_target = (float)race_manager->getCoinTarget();
-    int th = (int)(h*(coin_target/MAX_HERRING_EATEN));
+    int th = (int)(h*(coin_target/MAX_ITEMS_COLLECTED));
 
     glDisable(GL_TEXTURE_2D);
     // Draw a Meter border
@@ -648,71 +600,6 @@ void RaceGUI::drawEnergyMeter ( Kart *player_kart, int offset_x, int offset_y,
     glEnable(GL_TEXTURE_2D);
 }   // drawEnergyMeter
 
-
-//-----------------------------------------------------------------------------
-void RaceGUI::drawSteering(Kart* kart, int offset_x, int offset_y,
-                           float ratio_x, float ratio_y           )
-{
-
-    float minRatio = std::min(ratio_x, ratio_y);
-#define WHEELWIDTH 64
-    int width  = (int)(WHEELWIDTH*minRatio);
-    int height = (int)(WHEELWIDTH*minRatio);
-    offset_x += (int)((user_config->m_width-160)*ratio_x) - width;
-    offset_y += (int)(6*ratio_y);
-
-    glMatrixMode(GL_MODELVIEW);
-    glPushMatrix();
-    glLoadIdentity();
-    // for now we display the maximum steering as a 45 degree angle.
-    // One the steering angle for all karts are fixed, this should be
-    // changed, so that the user gets feedback about how much steering
-    // is currently done, since it will vary from kart to kart.
-    float displayedAngle = 45.0f * kart->getSteerPercent();
-
-    int tw = width/2; int th = height/2;
-    glTranslatef( (float)(offset_x+tw), (float)(offset_y+th), 0.0f);
-    glRotatef(displayedAngle, 0.0f, 0.0f, 1.0f);
-    glTranslatef((float)(-offset_x-tw), (float)(-offset_y-th), 0.0f);
-
-    m_steering_wheel_icon->getState()->force();
-    glBegin ( GL_QUADS ) ;
-    glColor4f    ( 1, 1, 1, 1 ) ;
-    glTexCoord2f(0, 0);glVertex2i(offset_x      , offset_y       );
-    glTexCoord2f(1, 0);glVertex2i(offset_x+width, offset_y       );
-    glTexCoord2f(1, 1);glVertex2i(offset_x+width, offset_y+height);
-    glTexCoord2f(0, 1);glVertex2i(offset_x      , offset_y+height);
-    glEnd () ;
-
-    glPopMatrix();
-} // drawSteering
-
-//-----------------------------------------------------------------------------
-void RaceGUI::drawPosition(Kart* kart, int offset_x, int offset_y,
-                           float ratio_x, float ratio_y           )
-{
-
-    char str[256];
-    offset_x += (int)((user_config->m_width-110)*ratio_x);
-    offset_y += (int)(140*ratio_y);
-
-    sprintf(str, "%d", kart->getPosition());
-    font_race->PrintShadow(str, (int)(100*ratio_y), offset_x, offset_y);
-
-    offset_x += (int)(50*ratio_x);
-    offset_y += (int)(50*ratio_y);
-
-    // FIXME: translation
-    if (kart->getPosition() == 1)
-        font_race->PrintShadow("st", (int)(40*ratio_y), offset_x, offset_y);
-    else if (kart->getPosition() == 2)
-        font_race->PrintShadow("nd", (int)(40*ratio_y), offset_x, offset_y);
-    else if (kart->getPosition() == 3)
-        font_race->PrintShadow("rd", (int)(40*ratio_y), offset_x, offset_y);
-    else
-        font_race->PrintShadow("th", (int)(40*ratio_y), offset_x, offset_y);
-} // drawPosition
-
 //-----------------------------------------------------------------------------
 void RaceGUI::drawSpeed(Kart* kart, int offset_x, int offset_y,
                         float ratio_x, float ratio_y           )
@@ -727,6 +614,9 @@ void RaceGUI::drawSpeed(Kart* kart, int offset_x, int offset_y,
 
     glMatrixMode(GL_MODELVIEW);
     m_speed_back_icon->getState()->force();
+    // If the colour isn't set, the speedometer is blended with the last
+    // used colour.
+    glColor4f(1,1,1,1);
     glBegin ( GL_QUADS ) ;
     glTexCoord2f(0, 0);glVertex2i(offset_x      , offset_y       );
     glTexCoord2f(1, 0);glVertex2i(offset_x+width, offset_y       );
@@ -748,22 +638,13 @@ void RaceGUI::drawSpeed(Kart* kart, int offset_x, int offset_y,
                                offset_y+(int)(10*minRatio));
     else
     {
-        if ( speed >= kart->getMaxSpeed()*kart->getWheelieMaxSpeedRatio() )
-        {
-            font_race->PrintShadow("l", (int)(60*minRatio), 
-                                   offset_x+(int)(70*minRatio), offset_y);
-            font_race->PrintShadow("^", (int)(60*minRatio), 
-                                   offset_x+(int)(65*minRatio), 
-                                   offset_y+(int)(7*minRatio));
-        }
-
         float speedRatio = speed/KILOMETERS_PER_HOUR/110.0f;
         // The following does not work with wheelie or Zipper
         //float speedRatio = kart->getVelocity()->xyz[1]/(kart->getMaxSpeed();
 
         if ( speedRatio > 1 )
             speedRatio = 1;
-
+        
         m_speed_fore_icon->getState()->force();
         glBegin ( GL_POLYGON ) ;
         glTexCoord2f(1, 0);glVertex2i(offset_x+width, offset_y);
@@ -784,46 +665,49 @@ void RaceGUI::drawSpeed(Kart* kart, int offset_x, int offset_y,
 } // drawSpeed
 
 //-----------------------------------------------------------------------------
-void RaceGUI::drawLap(Kart* kart, int offset_x, int offset_y,
-                      float ratio_x, float ratio_y           )
+void RaceGUI::drawLap(const KartIconDisplayInfo* info, Kart* kart, int offset_x,
+                      int offset_y, float ratio_x, float ratio_y           )
 {
     // Don't display laps in follow the leader mode
-    if(!race_manager->raceHasLaps()) return;
-
-    float maxRatio = std::max(ratio_x, ratio_y);
+    if(!RaceManager::getWorld()->raceHasLaps()) return;
+    
+    const int lap = info[kart->getWorldKartId()].lap;
+    
+    if(lap<0) return;  // don't display 'lap 0/...', or do nothing if laps are disabled (-1)
+    float minRatio = std::min(ratio_x, ratio_y);
     char str[256];
     offset_x += (int)(120*ratio_x);
-    offset_y += (int)(70*maxRatio);
+    offset_y += (int)(70*minRatio);
 
-    if ( kart->getLap() >= race_manager->getNumLaps())
+    if(kart->hasFinishedRace())
     {
         sprintf(str, _("Finished"));
-        font_race->PrintShadow(str, (int)(48*maxRatio), offset_x, offset_y);
+        font_race->PrintShadow(str, (int)(48*minRatio), offset_x, offset_y);
     }
     else
     {
-        font_race->PrintShadow( _("Lap"), (int)(48*maxRatio), offset_x, offset_y);
+        font_race->PrintShadow( _("Lap"), (int)(48*minRatio), offset_x, offset_y);
 
         offset_y -= (int)(50*ratio_y);
 
-        sprintf(str, "%d/%d", kart->getLap()<0?0:kart->getLap()+1, 
+        sprintf(str, "%d/%d", lap < 0 ? 0 : lap+1, 
                 race_manager->getNumLaps());
-        font_race->PrintShadow(str, (int)(48*maxRatio), offset_x, offset_y);
+        font_race->PrintShadow(str, (int)(48*minRatio), offset_x, offset_y);
     }
 } // drawLap
 
 //-----------------------------------------------------------------------------
 /** Removes messages which have been displayed long enough. This function
- *  must be called after drawAllMessages, otherwise messages which are onlu
+ *  must be called after drawAllMessages, otherwise messages which are only
  *  displayed once will not be drawn!
  **/
 
-void RaceGUI::cleanupMessages()
+void RaceGUI::cleanupMessages(const float dt)
 {
     AllMessageType::iterator p =m_messages.begin(); 
     while(p!=m_messages.end())
     {
-        if((*p).done())
+        if((*p).done(dt))
         {
             p = m_messages.erase(p);
         }
@@ -873,7 +757,7 @@ void RaceGUI::drawAllMessages(Kart* player_kart, int offset_x, int offset_y,
  *  certain amount of time (unless time<0, then the message is displayed
  *  once).
  **/
-void RaceGUI::addMessage(const char *msg, Kart *kart, float time, 
+void RaceGUI::addMessage(const std::string &msg, const Kart *kart, float time, 
                          int font_size, int red, int green, int blue)
 {
     m_messages.push_back(TimedMessage(msg, kart, time, font_size, red, green, blue));
@@ -902,7 +786,7 @@ void RaceGUI::drawMusicDescription()
 //-----------------------------------------------------------------------------
 void RaceGUI::drawStatusText(const float dt)
 {
-    assert(world != NULL);
+    assert(RaceManager::getWorld() != NULL);
 
     glMatrixMode   ( GL_MODELVIEW ) ;
     glPushMatrix   () ;
@@ -922,29 +806,32 @@ void RaceGUI::drawStatusText(const float dt)
     glEnable       ( GL_BLEND        );
 
     glOrtho        ( 0, user_config->m_width, 0, user_config->m_height, 0, 100 ) ;
-    switch (world->getPhase())
+    switch (RaceManager::getWorld()->getPhase())
     {
-    case World::READY_PHASE:
+    case READY_PHASE:
         {
             GLfloat const COLORS[] = { 0.9f, 0.66f, 0.62f, 1.0f };
+            //I18N: as in "ready, set, go", shown at the beginning of the race
             font_race->PrintShadow( _("Ready!"), 90,
                                    Font::CENTER_OF_SCREEN,
                                    Font::CENTER_OF_SCREEN,
                                    COLORS );
         }
         break;
-    case World::SET_PHASE:
+    case SET_PHASE:
         {
             GLfloat const COLORS[] = { 0.9f, 0.9f, 0.62f, 1.0f };
+            //I18N: as in "ready, set, go", shown at the beginning of the race
             font_race->PrintShadow( _("Set!"), 90,
                                    Font::CENTER_OF_SCREEN,
                                    Font::CENTER_OF_SCREEN,
                                    COLORS );
         }
         break;
-    case World::GO_PHASE:
+    case GO_PHASE:
         {
             GLfloat const COLORS[] = { 0.39f, 0.82f, 0.39f, 1.0f };
+            //I18N: as in "ready, set, go", shown at the beginning of the race
             font_race->PrintShadow( _("Go!"), 90, 
                                    Font::CENTER_OF_SCREEN,
                                    Font::CENTER_OF_SCREEN,
@@ -957,23 +844,32 @@ void RaceGUI::drawStatusText(const float dt)
 
     for(int i = 0; i < 10; ++i)
     {
-        if(world->m_debug_text[i] != "")
+        if(RaceManager::getWorld()->m_debug_text[i] != "")
         {
             GLfloat const COLORS[] = { 0.39f, 0.82f, 0.39f, 1.0f };
-            font_race->Print( world->m_debug_text[i].c_str(),
+            font_race->Print( RaceManager::getWorld()->m_debug_text[i].c_str(),
                              20, 20, 200 -i*20, COLORS );
         }
     }
+
+    float split_screen_ratio_x, split_screen_ratio_y;
+    split_screen_ratio_x = split_screen_ratio_y = 1.0;
+    if(race_manager->getNumLocalPlayers() >= 2)
+        split_screen_ratio_y = 0.5;
+    if(race_manager->getNumLocalPlayers() >= 3)
+        split_screen_ratio_x = 0.5;
+
     // The penalty message needs to be displayed for up to one second
     // after the start of the race, otherwise it disappears if 
     // "Go" is displayed and the race starts
-    if(world->isStartPhase() || world->getTime()<1.0f)
+    if(RaceManager::getWorld()->isStartPhase() || RaceManager::getWorld()->getTime()<1.0f)
     {
-        for(unsigned int i=0; i<race_manager->getNumPlayers(); i++)
+        for(unsigned int i=0; i<race_manager->getNumLocalPlayers(); i++)
         {
-            if(world->getPlayerKart(i)->earlyStartPenalty())
+            if(RaceManager::getWorld()->getLocalPlayerKart(i)->earlyStartPenalty())
             {
                 GLfloat const COLORS[] = { 0.78f, 0.025f, 0.025f, 1.0f };
+
                 font_race->PrintShadow( _("Penalty time!!"), 80,
                                        Font::CENTER_OF_SCREEN, 200,
                                         COLORS );
@@ -981,21 +877,16 @@ void RaceGUI::drawStatusText(const float dt)
         }  // for i < getNumPlayers
     }  // if not RACE_PHASE
 
-    float split_screen_ratio_x, split_screen_ratio_y;
-    split_screen_ratio_x = split_screen_ratio_y = 1.0;
-    if(race_manager->getNumPlayers() >= 2)
-        split_screen_ratio_y = 0.5;
-    if(race_manager->getNumPlayers() >= 3)
-        split_screen_ratio_x = 0.5;
 
-    if ( world->isRacePhase() )
+    if ( RaceManager::getWorld()->isRacePhase() )
     {
-        const int numPlayers = race_manager->getNumPlayers();
+        KartIconDisplayInfo* info = RaceManager::getWorld()->getKartsDisplayInfo(this);
+        
+        const int numPlayers = race_manager->getNumLocalPlayers();
 
         for(int pla = 0; pla < numPlayers; pla++)
         {
-            int offset_x, offset_y;
-            offset_x = offset_y = 0;
+            int offset_x = 0, offset_y = 0;
 
             if(numPlayers == 2)
             {
@@ -1024,35 +915,51 @@ void RaceGUI::drawStatusText(const float dt)
                 offset_x = user_config->m_width/2;
             }
 
-            Kart* player_kart=world->getPlayerKart(pla);
-            drawCollectableIcons(player_kart, offset_x, offset_y,
+            Kart* player_kart = RaceManager::getWorld()->getLocalPlayerKart(pla);
+            drawPowerupIcons(player_kart, offset_x, offset_y,
                                  split_screen_ratio_x, split_screen_ratio_y );
             drawEnergyMeter     (player_kart, offset_x, offset_y,
                                  split_screen_ratio_x, split_screen_ratio_y );
-            drawSteering        (player_kart, offset_x, offset_y,
-                                 split_screen_ratio_x, split_screen_ratio_y );
-            drawPosition        (player_kart, offset_x, offset_y,
-                                 split_screen_ratio_x, split_screen_ratio_y );
             drawSpeed           (player_kart, offset_x, offset_y,
                                  split_screen_ratio_x, split_screen_ratio_y );
-            drawLap             (player_kart, offset_x, offset_y,
+            drawLap             (info, player_kart, offset_x, offset_y,
                                  split_screen_ratio_x, split_screen_ratio_y );
             drawAllMessages     (player_kart, offset_x, offset_y,
                                  split_screen_ratio_x, split_screen_ratio_y );
-        }   // for pla
-        drawTimer           ();
-        if(world->getTime()<TIME_MUSIC_DESCRIPTION 
-          && race_manager->getRaceMode() != RaceManager::RM_FOLLOW_LEADER)
+            
+            if(player_kart->hasViewBlockedByPlunger())
+            {
+                const int screen_width = (numPlayers > 2) ? user_config->m_width/2 : user_config->m_width;
+                const int plunger_size = (numPlayers > 1) ? user_config->m_height/2 : user_config->m_height;
+                int plunger_x = offset_x + screen_width/2 - plunger_size/2;
+                
+                if (numPlayers == 3 && pla > 1)
+                    plunger_x = offset_x + user_config->m_width/2 - plunger_size/2;
+                        
+                m_plunger_face->getState()->force();
+                glBegin ( GL_QUADS ) ;
+                glTexCoord2f(1, 0); glVertex2i(plunger_x+plunger_size,    offset_y);
+                glTexCoord2f(0, 0); glVertex2i(plunger_x,                 offset_y);
+                glTexCoord2f(0, 1); glVertex2i(plunger_x,                 offset_y+plunger_size);
+                glTexCoord2f(1, 1); glVertex2i(plunger_x+plunger_size,    offset_y+plunger_size);
+                glEnd () ;                
+            }
+        }   // next player
+        
+        drawTimer();
+        
+        if(RaceManager::getWorld()->getPhase() == GO_PHASE ||
+           RaceManager::getWorld()->getPhase() == MUSIC_PHASE)
         {
             drawMusicDescription();
         }
-        else if (world->getTime()>stk_config->m_leader_intervals[0]-TIME_MUSIC_DESCRIPTION 
-          && race_manager->getRaceMode()== RaceManager::RM_FOLLOW_LEADER)
-            drawMusicDescription();
+
             
-        drawMap             ();
-        if ( user_config->m_display_fps ) drawFPS ();
-        drawPlayerIcons     ();
+        drawMap();
+        if ( user_config->m_display_fps ) drawFPS();
+        
+        drawPlayerIcons(info);
+        
     }   // if RACE_PHASE
 
     glPopAttrib  () ;
