@@ -1,4 +1,4 @@
-//  $Id: race_gui.hpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: race_gui.hpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004-2005 Steve Baker <sjbaker1@airmail.net>
@@ -6,7 +6,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -25,16 +25,30 @@
 #include <vector>
 
 #include "base_gui.hpp"
-#include "kart.hpp"
 #include "material.hpp"
-#include "player_kart.hpp"
 #include "player.hpp"
-#include "world.hpp"
 #include "race_manager.hpp"
+#include "karts/kart.hpp"
+#include "karts/player_kart.hpp"
+#include "modes/world.hpp"
 
 class InputMap;
 class RaceSetup;
 
+/**
+  * Used to display the list of karts and their times or
+  * whatever other info is relevant to the current mode.
+  */
+struct KartIconDisplayInfo
+{
+    std::string time;
+    float r, g, b;
+    std::string special_title;
+    /** Current lap of this kart, or -1 if irrelevant
+      */
+    int lap;
+};
+
 class RaceGUI: public BaseGUI
 {
 
@@ -42,32 +56,33 @@ class RaceGUI: public BaseGUI
     {
      public:
         std::string m_message;            // message to display
-        float       m_end_time;           // end time for the message (-1 if once only)
+        float       m_remaining_time;     // time remaining before removing this message from screen
         int         m_red,m_blue,m_green; // colour
         int         m_font_size;          // size
-        Kart        *m_kart;
+        const Kart *m_kart;
         // std::vector needs standard copy-ctor and std-assignment op.
         // let compiler create defaults .. they'll do the job, no
         // deep copies here ..
-        TimedMessage(const char *message, 
-                     Kart *kart, float time, int size, 
+        TimedMessage(const std::string &message, 
+                     const Kart *kart, float time, int size, 
                      int red, int green, int blue)
         {
             m_message    = message; 
             m_font_size  = size;
             m_kart       = kart;
-            m_end_time   = time>=0.0f 
-                         ? (race_manager->getRaceMode()==RaceManager::RM_FOLLOW_LEADER 
-                            ?world->getTime()-time
-                            :world->getTime()+time )
-                         : -1.0f;
+            if( time < 0.0f ) m_remaining_time = -1.0f;
+            else
+            {
+                m_remaining_time = time;
+            }
             m_red=red; m_blue=blue; m_green=green; 
         }
         // in follow leader the clock counts backwards
-        bool done() const {return m_end_time<0 || 
-                           (race_manager->getRaceMode()==RaceManager::RM_FOLLOW_LEADER 
-                                  ? world->getTime()<m_end_time
-                                  : world->getTime()>m_end_time);}
+        bool done(const float dt)
+        {
+            m_remaining_time -= dt;
+            return m_remaining_time < 0;
+        }
     };
 public:
 
@@ -77,18 +92,18 @@ public:
     void select() {}
     void handle(GameAction, int);
     void handleKartAction(KartAction ka, int value);
-    void addMessage(const char *message, Kart *kart, float time, int fonst_size,
-                    int red=255, int green=0, int blue=255);
+    void addMessage(const std::string &m, const Kart *kart, float time, 
+                    int fonst_size, int red=255, int green=0, int blue=255);
 
 private:
-    ulClock     m_fps_timer;
-    int         m_fps_counter;
-    char        m_fps_string[10];
-    const char* m_pos_string [11];
-    Material*   m_steering_wheel_icon;
-    Material*   m_speed_back_icon;
-    Material* m_speed_fore_icon;
-    typedef   std::vector<TimedMessage> AllMessageType;
+    ulClock        m_fps_timer;
+    int            m_fps_counter;
+    char           m_fps_string[10];
+    const char    *m_pos_string [11];
+    Material      *m_speed_back_icon;
+    Material      *m_speed_fore_icon;
+    Material      *m_plunger_face;
+    typedef        std::vector<TimedMessage> AllMessageType;
     AllMessageType m_messages;
 
     /* Display informat on screen */
@@ -96,32 +111,23 @@ private:
     void drawEnergyMeter       (Kart *player_kart,
                                 int   offset_x, int   offset_y,
                                 float ratio_x,  float ratio_y  );
-    void drawCollectableIcons  (Kart* player_kart,
+    void drawPowerupIcons  (Kart* player_kart,
                                 int   offset_x, int   offset_y,
                                 float ratio_x,  float ratio_y  );
     void drawAllMessages       (Kart* player_kart,
                                 int   offset_x, int   offset_y,
                                 float ratio_x,  float ratio_y  );
-    void drawPlayerIcons       ();
+    void drawPlayerIcons       (const KartIconDisplayInfo* info);
     void oldDrawPlayerIcons    ();
     void drawMap               ();
     void drawTimer             ();
     void drawFPS               ();
     void drawMusicDescription  ();
-    void cleanupMessages       ();
-
-    /* Text drawing */
-    /** Draw text to screen.
-        scale_x and scale_y could be used to a simple resize (e.g. for multiplayer
-        split screens, though, currently, we reduce fonts size to half).        */
-    void drawSteering             (Kart* kart, int offset_x, int offset_y,
-                                   float ratio_x, float ratio_y           );
-    void drawPosition             (Kart* kart, int offset_x, int offset_y,
-                                   float ratio_x, float ratio_y           );
+    void cleanupMessages       (const float dt);
     void drawSpeed                (Kart* kart, int offset_x, int offset_y,
                                    float ratio_x, float ratio_y           );
-    void drawLap                  (Kart* kart, int offset_x, int offset_y,
-                                   float ratio_x, float ratio_y           );
+    void drawLap                  (const KartIconDisplayInfo* info, Kart* kart, int offset_x,
+                                   int offset_y, float ratio_x, float ratio_y  );
 };
 
 #endif
