@@ -1,4 +1,4 @@
-//  $Id: race_menu.cpp 3034 2009-01-23 05:23:22Z hikerstk $
+//  $Id: race_menu.cpp 3833 2009-08-11 12:07:12Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -91,7 +91,7 @@ void RaceMenu::select()
     case WTOK_RESTART_RACE:
         menu_manager->popMenu();
         if(user_config->m_fullscreen) SDL_ShowCursor(SDL_DISABLE);
-        RaceManager::getWorld()->restartRace();
+        race_manager->rerunRace();
         break;
 
     case WTOK_OPTIONS:
