@@ -3,7 +3,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -25,13 +25,17 @@ class RaceOptions: public BaseGUI
 private:
     int m_difficulty;
     int m_num_karts;
+    int m_min_karts;         // minimum number of karts, depending on mode etc.
     int m_num_laps;
     const char *getDifficultyString(int) const;
+    void setAllValues();
 public:
     RaceOptions();
     ~RaceOptions();
 
     void select();
+    void update(float dt);
+    virtual void handle(GameAction, int);
 };
 
 #endif
