@@ -3,7 +3,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,10 +20,19 @@
 
 #include "base_gui.hpp"
 
+/** This class is used to give feedback to the user while loading the track.
+ *  It either displays a 'Loading track' or a 'Wait for synchronisation'
+ *  message (dependent on the stage of the race manager).
+ */
 class StartRaceFeedback: public BaseGUI
 {
-    bool m_updated;
-
+protected:
+    /** Flag used to make sure that the text is actually displayed (i.e
+     *  update was called once) before loading the track - otherwise the
+     *  text is set in the widget, but not on the screen since the screen
+     *  wasn't updated.
+     */
+    bool m_is_first_frame;
 public:
     StartRaceFeedback();
     ~StartRaceFeedback();
