@@ -1,4 +1,4 @@
-//  $Id: lexer.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: lexer.cpp 3037 2009-01-25 19:57:13Z auria $
 //
 //  TuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004 Matthias Braun <matze@braunis.de>
@@ -6,7 +6,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -19,13 +19,11 @@
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <sstream>
 #include <stdexcept>
+#include <cstdio>
 #include <cstring>
 
-#include "lexer.hpp"
-#include "translation.hpp"
-#if defined(WIN32) && !defined(__CYGWIN__)
-#  define snprintf _snprintf
-#endif
+#include "lisp/lexer.hpp"
+
 namespace lisp
 {
 
@@ -149,11 +147,10 @@ namespace lisp
                     }
                     catch(EOFException& )
                     {
-                        char msg[MAX_ERROR_MESSAGE_LENGTH];
-                        snprintf(msg, sizeof(msg),
-                                 "Parse error in line %d: EOF while parsing string.",
-                                 STARTLINE);
-                        throw std::runtime_error(msg);
+                        std::ostringstream msg;
+                        msg << "Parse error in line " << STARTLINE
+                            << ": EOF while parsing string.";
+                        throw std::runtime_error(msg.str());
                     }
                     nextChar();
                     return TOKEN_STRING;
@@ -173,11 +170,10 @@ namespace lisp
                 }
                 catch(EOFException& )
                 {
-                    char msg[MAX_ERROR_MESSAGE_LENGTH];
-                    snprintf(msg, sizeof(msg), 
-                             "Parse Error in line %d: EOF while parsing constant.",
-                             m_line_number);
-                    throw std::runtime_error(msg);
+                    std::ostringstream msg;
+                    msg << "Parse Error in line " << m_line_number
+                        << ": EOF while parsing constant.";
+                    throw std::runtime_error(msg.str());
                 }
 
                 if(strcmp(m_token_string, "t") == 0)
@@ -189,11 +185,10 @@ namespace lisp
                 // constants
 
                 {
-                    char msg[MAX_ERROR_MESSAGE_LENGTH];
-                    snprintf(msg, sizeof(msg), 
-                             "Parse Error in line %d: Unknown constant '%s'.",
-                             m_line_number, m_token_string);
-                    throw std::runtime_error(msg);
+                    std::ostringstream msg;
+                    msg << "Parse Error in line " << m_line_number 
+                        << ": Unknown constant '" << m_token_string<<"'.";
+                    throw std::runtime_error(msg.str());
                 }
 
             case '_': // can be begin translation
