@@ -1,4 +1,4 @@
-//  $Id: parser.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: parser.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  TuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004 Matthias Braun <matze@braunis.de>
@@ -6,7 +6,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,9 +21,10 @@
 #include <stdexcept>
 #include <fstream>
 
-#include "parser.hpp"
-#include "lisp.hpp"
-#include "translation.hpp"
+#include "lisp/parser.hpp"
+#include "lisp/lisp.hpp"
+#include "utils/translation.hpp"
+
 #if defined(WIN32) && !defined(__CYGWIN__)
 #  define snprintf _snprintf
 #endif
@@ -83,7 +84,7 @@ namespace lisp
     Lisp*
     Parser::read()
     {
-        Lisp* result;
+        Lisp* result=NULL;
         switch(m_token)
         {
         case Lexer::TOKEN_EOF:
