@@ -1,4 +1,4 @@
-//  $Id: track.cpp 3034 2009-01-23 05:23:22Z hikerstk $
+//  $Id: track.cpp 3834 2009-08-11 12:27:04Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004 Steve Baker <sjbaker1@airmail.net>
@@ -1413,9 +1413,8 @@ void Track::loadTrackModel()
     file_manager->popTextureSearchPath();
     file_manager->popModelSearchPath  ();
 
-    Vec3 min, max;
-    SSGHelp::MinMax(m_model, &min, &max);
-    RaceManager::getWorld()->getPhysics()->init(min, max);
+    SSGHelp::MinMax(m_model, &m_aabb_min, &m_aabb_max);
+    RaceManager::getWorld()->getPhysics()->init(m_aabb_min, m_aabb_max);
     createPhysicsModel();
 }   // loadTrack
 
